@@ -104,8 +104,11 @@ class BzrBranch(object):
 
     def get_changes(self):
         """Return a list of changes"""
-        return self.get_workingtree().changes_from(
-            self.get_oldtree(), want_unversioned=True)
+        try:
+            return self.get_workingtree().changes_from(
+                self.get_oldtree(), want_unversioned=True)
+        except AssertionError, message:
+            logging.error("Couldn't update view, %s" % message)
 
     def push_revno(self, set_to=None):
         """The revision number of the last push."""
@@ -351,6 +354,8 @@ class BazaarStatusApp(StatusApp):
         if kwargs.has_key('directory') and not kwargs['directory']:
             kwargs['directory'] = self.branch.location
         cmd.run( **kwargs )
+        # Make sure to clean up
+        cmd.cleanup_now()
 
     def write(self, content):
         """Being used as a file handle, write out"""
@@ -499,8 +504,6 @@ class RevertStatusApp(BazaarStatusApp):
         clean_tree(loc, unknown=True, ignored=False, detritus=True,
                    dry_run=False, no_prompt=True)
         self.do_command('revert', file_list=[ loc ])
-        # XXX Possible bug, why do I need to force the destroy here?
-        self._loaded['status_window'].destroy_window()
 
 
 class MergeStatusApp(BazaarStatusApp):
